@@ -217,7 +217,6 @@ typedef struct {
     SA_SC_DECLARE_3(ssize_t,          write,         int, const void *, size_t)
     SA_SC_DECLARE_6(ssize_t,          recvfrom,      int, void *, size_t, int, struct sockaddr *, socklen_t *)
     SA_SC_DECLARE_6(ssize_t,          sendto,        int, const void *, size_t, int, const struct sockaddr *, socklen_t)
-    SA_SC_DECLARE_1(struct hostent *, gethostbyname, const char *name)
 } sa_syscall_tab_t;
 
 /* socket option information */
@@ -267,14 +266,16 @@ static int sa_inet_pton(int family, const char *strptr, void *addrptr)
            and for IPv6 inet_pton(3) would exist anyway */
         if (inet_aton(strptr, &in_val) == 0)
             return 0;
+        memcpy(addrptr, &in_val, sizeof(struct in_addr));
+        return 1;
 #elif defined(HAVE_INET_ADDR)
         /* at least for IPv4 try to rely on the even older inet_addr(3) */
         memset(&in_val, '\0', sizeof(in_val));
         if ((in_val.s_addr = inet_addr(strptr)) == ((in_addr_t)-1))
             return 0;
-#endif
         memcpy(addrptr, &in_val, sizeof(struct in_addr));
         return 1;
+#endif
     }
     errno = EAFNOSUPPORT;
     return 0;
@@ -653,7 +654,7 @@ sa_rc_t sa_addr_u2a(sa_addr_t *saa, const char *uri, ...)
             sf = AF_INET6;
         }
 #endif
-        else if ((he = SA_SC_CALL_1(sa, gethostbyname, cpHost)) != NULL) {
+        else if ((he = gethostbyname(cpHost)) != NULL) {
             if (he->h_addrtype == AF_INET) {
                 sa4.sin_family = AF_INET;
                 sa4.sin_port = htons(nPort);
@@ -732,7 +733,7 @@ sa_rc_t sa_addr_s2a(sa_addr_t *saa, const struct sockaddr *sabuf, socklen_t sale
 }
 
 /* export address object into URI */
-sa_rc_t sa_addr_a2u(sa_addr_t *saa, char **uri)
+sa_rc_t sa_addr_a2u(const sa_addr_t *saa, char **uri)
 {
     char uribuf[1024];
     struct sockaddr_un *un;
@@ -793,7 +794,7 @@ sa_rc_t sa_addr_a2u(sa_addr_t *saa, char **uri)
 }
 
 /* export address object into "struct sockaddr" */
-sa_rc_t sa_addr_a2s(sa_addr_t *saa, struct sockaddr **sabuf, socklen_t *salen)
+sa_rc_t sa_addr_a2s(const sa_addr_t *saa, struct sockaddr **sabuf, socklen_t *salen)
 {
     /* argument sanity check(s) */
     if (saa == NULL || sabuf == NULL || salen == 0)
@@ -808,7 +809,7 @@ sa_rc_t sa_addr_a2s(sa_addr_t *saa, struct sockaddr **sabuf, socklen_t *salen)
     return SA_OK;
 }
 
-sa_rc_t sa_addr_match(sa_addr_t *saa1, sa_addr_t *saa2, int prefixlen)
+sa_rc_t sa_addr_match(const sa_addr_t *saa1, const sa_addr_t *saa2, int prefixlen)
 {
     const unsigned char *ucp1, *ucp2;
     unsigned int uc1, uc2, mask;
@@ -934,7 +935,7 @@ sa_rc_t sa_addr_match(sa_addr_t *saa1, sa_addr_t *saa2, int prefixlen)
 }
 
 /* set timeouts if timeouts or done in kernel */
-static sa_rc_t sa_socket_settimeouts(sa_t *sa)
+static sa_rc_t sa_socket_settimeouts(const sa_t *sa)
 {
     /* stop processing if socket is still not allocated */
     if (sa->fdSocket == -1)
@@ -1183,7 +1184,6 @@ sa_rc_t sa_create(sa_t **sap)
     SA_SC_ASSIGN(sa, write,         write,         NULL);
     SA_SC_ASSIGN(sa, recvfrom,      recvfrom,      NULL);
     SA_SC_ASSIGN(sa, sendto,        sendto,        NULL);
-    SA_SC_ASSIGN(sa, gethostbyname, gethostbyname, NULL);
 
     /* pass object to caller */
     *sap = sa;
@@ -1222,7 +1222,7 @@ sa_rc_t sa_type(sa_t *sa, sa_type_t type)
 
     /* kill underlying socket if type changes */
     if (sa->eType != type)
-        sa_socket_kill(sa);
+        (void)sa_socket_kill(sa);
 
     /* set new type */
     sa->eType = type;
@@ -1413,7 +1413,6 @@ sa_rc_t sa_syscall(sa_t *sa, sa_syscall_t id, void (*fptr)(void), void *fctx)
         case SA_SYSCALL_WRITE:         SA_SC_ASSIGN(sa, write,         fptr, fctx); break;
         case SA_SYSCALL_RECVFROM:      SA_SC_ASSIGN(sa, recvfrom,      fptr, fctx); break;
         case SA_SYSCALL_SENDTO:        SA_SC_ASSIGN(sa, sendto,        fptr, fctx); break;
-        case SA_SYSCALL_GETHOSTBYNAME: SA_SC_ASSIGN(sa, gethostbyname, fptr, fctx); break;
         default: rv = SA_ERR_ARG;
     }
 
@@ -1421,7 +1420,7 @@ sa_rc_t sa_syscall(sa_t *sa, sa_syscall_t id, void (*fptr)(void), void *fctx)
 }
 
 /* bind socket to a local address */
-sa_rc_t sa_bind(sa_t *sa, sa_addr_t *laddr)
+sa_rc_t sa_bind(sa_t *sa, const sa_addr_t *laddr)
 {
     sa_rc_t rv;
     struct sockaddr_un *un;
@@ -1449,7 +1448,7 @@ sa_rc_t sa_bind(sa_t *sa, sa_addr_t *laddr)
 }
 
 /* connect socket to a remote address */
-sa_rc_t sa_connect(sa_t *sa, sa_addr_t *raddr)
+sa_rc_t sa_connect(sa_t *sa, const sa_addr_t *raddr)
 {
     int flags, n, error;
     fd_set rset, wset;
@@ -1657,7 +1656,6 @@ sa_rc_t sa_accept(sa_t *sa, sa_addr_t **caddr, sa_t **csa)
     SA_SC_COPY((*csa), sa, write);
     SA_SC_COPY((*csa), sa, recvfrom);
     SA_SC_COPY((*csa), sa, sendto);
-    SA_SC_COPY((*csa), sa, gethostbyname);
 
     /* copy-over original timeout values */
     for (i = 0; i < (int)(sizeof(sa->tvTimeout)/sizeof(sa->tvTimeout[0])); i++) {
@@ -2131,7 +2129,7 @@ sa_rc_t sa_flush(sa_t *sa)
 }
 
 /* shutdown a socket connection */
-sa_rc_t sa_shutdown(sa_t *sa, char *flags)
+sa_rc_t sa_shutdown(sa_t *sa, const char *flags)
 {
     int how;
 
